@@ -36,8 +36,7 @@ logger = logging.getLogger(__name__)
 
 @dataclasses.dataclass()
 class Session(Obj, EnvironmentMixin):
-    """
-    A :term:`tmux(1)` :term:`Session` [session_manual]_.
+    """:term:`tmux(1)` :term:`Session` [session_manual]_.
 
     Holds :class:`Window` objects.
 
@@ -78,7 +77,9 @@ class Session(Obj, EnvironmentMixin):
         """Refresh session attributes from tmux."""
         assert isinstance(self.session_id, str)
         return super()._refresh(
-            obj_key="session_id", obj_id=self.session_id, list_cmd="list-sessions"
+            obj_key="session_id",
+            obj_id=self.session_id,
+            list_cmd="list-sessions",
         )
 
     @classmethod
@@ -96,8 +97,8 @@ class Session(Obj, EnvironmentMixin):
     # Relations
     #
     @property
-    def windows(self) -> QueryList["Window"]:  # type:ignore
-        """Windows belonging session.
+    def windows(self) -> QueryList["Window"]:
+        """Windows contained by session.
 
         Can be accessed via
         :meth:`.windows.get() <libtmux._internal.query_list.QueryList.get()>` and
@@ -116,8 +117,8 @@ class Session(Obj, EnvironmentMixin):
         return QueryList(windows)
 
     @property
-    def panes(self) -> QueryList["Pane"]:  # type:ignore
-        """Panes belonging session.
+    def panes(self) -> QueryList["Pane"]:
+        """Panes contained by session's windows.
 
         Can be accessed via
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
@@ -139,8 +140,7 @@ class Session(Obj, EnvironmentMixin):
     # Command
     #
     def cmd(self, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """
-        Return :meth:`server.cmd`.
+        """Execute tmux subcommand against target session. See :meth:`server.cmd`.
 
         Returns
         -------
@@ -171,10 +171,12 @@ class Session(Obj, EnvironmentMixin):
     """
 
     def set_option(
-        self, option: str, value: t.Union[str, int], _global: bool = False
+        self,
+        option: str,
+        value: t.Union[str, int],
+        _global: bool = False,
     ) -> "Session":
-        """
-        Set option ``$ tmux set-option <option> <value>``.
+        """Set option ``$ tmux set-option <option> <value>``.
 
         Parameters
         ----------
@@ -223,13 +225,10 @@ class Session(Obj, EnvironmentMixin):
         return self
 
     def show_options(
-        self, _global: t.Optional[bool] = False
+        self,
+        _global: t.Optional[bool] = False,
     ) -> t.Dict[str, t.Union[str, int]]:
-        """
-        Return a dict of options for the window.
-
-        For familiarity with tmux, the option ``option`` param forwards to pick
-        a single option, forwarding to :meth:`Session.show_option`.
+        """Return dict of options for the session.
 
         Parameters
         ----------
@@ -265,9 +264,11 @@ class Session(Obj, EnvironmentMixin):
         return session_options
 
     def show_option(
-        self, option: str, _global: bool = False
+        self,
+        option: str,
+        _global: bool = False,
     ) -> t.Optional[t.Union[str, int, bool]]:
-        """Return a list of options for the window.
+        """Return option value for the target session.
 
         Parameters
         ----------
@@ -319,8 +320,7 @@ class Session(Obj, EnvironmentMixin):
         return value
 
     def select_window(self, target_window: t.Union[str, int]) -> "Window":
-        """
-        Return :class:`Window` selected via ``$ tmux select-window``.
+        """Select window, return selected window.
 
         Parameters
         ----------
@@ -380,15 +380,14 @@ class Session(Obj, EnvironmentMixin):
         return self
 
     def kill_session(self) -> None:
-        """``$ tmux kill-session``."""
+        """Destroy session."""
         proc = self.cmd("kill-session", "-t%s" % self.session_id)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
     def switch_client(self) -> "Session":
-        """
-        Switch client to this session.
+        """Switch client to session.
 
         Raises
         ------
@@ -402,8 +401,7 @@ class Session(Obj, EnvironmentMixin):
         return self
 
     def rename_session(self, new_name: str) -> "Session":
-        """
-        Rename session and return new :class:`Session` object.
+        """Rename session and return new :class:`Session` object.
 
         Parameters
         ----------
@@ -443,8 +441,7 @@ class Session(Obj, EnvironmentMixin):
         window_shell: t.Optional[str] = None,
         environment: t.Optional[t.Dict[str, str]] = None,
     ) -> "Window":
-        """
-        Return :class:`Window` from ``$ tmux new-window``.
+        """Create new window, returns new :class:`Window`.
 
         By default, this will make the window active. For the new window
         to be created and not set to current, pass in ``attach=False``.
@@ -499,7 +496,7 @@ class Session(Obj, EnvironmentMixin):
                     window_args += (f"-e{k}={v}",)
             else:
                 logger.warning(
-                    "Cannot set up environment as tmux 3.0 or newer is required."
+                    "Cannot set up environment as tmux 3.0 or newer is required.",
                 )
 
         if window_shell:
@@ -513,11 +510,12 @@ class Session(Obj, EnvironmentMixin):
         window_output = cmd.stdout[0]
 
         window_formatters = dict(
-            zip(["window_id"], window_output.split(FORMAT_SEPARATOR))
+            zip(["window_id"], window_output.split(FORMAT_SEPARATOR)),
         )
 
         return Window.from_window_id(
-            server=self.server, window_id=window_formatters["window_id"]
+            server=self.server,
+            window_id=window_formatters["window_id"],
         )
 
     def kill_window(self, target_window: t.Optional[str] = None) -> None:
@@ -615,11 +613,12 @@ class Session(Obj, EnvironmentMixin):
 
         """
         warnings.warn(
-            f"Item lookups, e.g. session['{key}'] is deprecated", stacklevel=2
+            f"Item lookups, e.g. session['{key}'] is deprecated",
+            stacklevel=2,
         )
         return getattr(self, key)
 
-    def get_by_id(self, id: str) -> t.Optional[Window]:
+    def get_by_id(self, session_id: str) -> t.Optional[Window]:
         """Return window by id. Deprecated in favor of :meth:`.windows.get()`.
 
         .. deprecated:: 0.16
@@ -628,7 +627,7 @@ class Session(Obj, EnvironmentMixin):
 
         """
         warnings.warn("Session.get_by_id() is deprecated", stacklevel=2)
-        return self.windows.get(window_id=id, default=None)
+        return self.windows.get(window_id=session_id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Window]:
         """Filter through windows, return list of :class:`Window`.
@@ -656,7 +655,7 @@ class Session(Obj, EnvironmentMixin):
         return self.windows.get(default=None, **kwargs)
 
     def _list_windows(self) -> t.List["WindowDict"]:
-        """Return list of windows (deprecated in favor of :meth:`.windows`).
+        """Return list of windows (deprecated in favor of :attr:`.windows`).
 
         .. deprecated:: 0.16
 
@@ -690,7 +689,7 @@ class Session(Obj, EnvironmentMixin):
         return self.windows
 
     @property
-    def children(self) -> QueryList["Window"]:  # type:ignore
+    def children(self) -> QueryList["Window"]:
         """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
